#uses "fwInstallation/fwInstallationManager.ctl"

/**
 * The function checks if a specific command/manager is already
 * present in the console and modify it if it is present
 * otherwise it simply adds the manager.
 * The need of this function came from the transition
 * from running unicos_scripts.lst without explicit 
 * manager number to running it with -num paramater, c.f. UNCORE-174
 * 
 * @param string sManager: the type of manager, e.g. WCCOActrl
 * @param string sOldCommandLine: the command line to be replaced, e.g. -f unicos_scripts.lst
 * @param string sNewCommandLine: the new command line replacing sOldCommandLine, e.g. -f unicos_scripts.lst -num 100
 * @return 1 if successful, negative number otherwise
 **/
int unCorePostInstall_modifyManagerCommandIfExistOrAdd( string sManager, string sOldCommandLine, string sNewCommandLine,
                                              string sMode="always", int secKill=2, int restartCount=2, int resetMin=30
                                              ){
  int manNum;
  if (fwInstallationManager_getNum( sManager, sOldCommandLine, manNum)!=0){
    dyn_string exceptionInfo;
    fwException_raise(exceptionInfo, "ERROR", "["+__FUNCTION__+"] Error while querying manager number of "+sOldCommandLine, ""); 
    return -1;
  }
  
  if (manNum==-1){
    //Manager does not exist yet, we simply need to add it
    return fwInstallationManager_add( sManager, sMode, secKill, restartCount, resetMin, sNewCommandLine);
  }

  dyn_mixed dmManProp;
  if ( fwInstallationManager_getProperties(sManager, sOldCommandLine, dmManProp) != 0){
    dyn_string exceptionInfo;
    fwException_raise(exceptionInfo, "ERROR", "["+__FUNCTION__+"] Unable to get properties of "+sOldCommandLine, ""); 
    return -2;
  }

  if (dynlen(dmManProp) < 7){
    dyn_string exceptionInfo;
    fwException_raise(exceptionInfo, "ERROR", "["+__FUNCTION__+"] Properties of "+sOldCommandLine + "do not have the expected format", ""); 
    return -3;
  }

  //if the command line is already the same, nothing to do
  if(dmManProp[7] == sNewCommandLine){
    return 1;
  }

  //modify the command line
  dmManProp[7] = sNewCommandLine;

  //and set the new command line
  if ( fwInstallationManager_setProperties(sManager, sOldCommandLine, dmManProp) != 0){
    dyn_string exceptionInfo;
    fwException_raise(exceptionInfo, "ERROR", "["+__FUNCTION__+"] Unable to set properties of "+sOldCommandLine, ""); 
    return -4;
  }

  return 1;
}