#uses "fwUnitTestComponentAsserts.ctl" 
#uses "libunCore/unManager.ctl"
#uses "postInstall/unicos/unCore/unManager.ctl"

//------------------------------------------------------------------
void test_unManager_setupSuite(){

}
 

//--------------------------------------------------------------------
//Once unCore is fully installed we should have
//all unicos ctrl managers  set with their correct numbers
void test_unManager_checkUnicosScriptsManagersNumber(){
  int iManNum;
  fwInstallationManager_getNum("WCCOActrl", "unicos_scripts.lst", iManNum);
  assertEqual( unManager_getUnicosScriptsManagerNumber(), iManNum, "unicos_scripts.lst does not have the excepted manager number");
}

void test_unManager_checkUnDistributedControlManagersNumber(){
  int iManNum;
  fwInstallationManager_getNum("WCCOActrl", "unDistributedControl.ctl", iManNum);
  assertEqual( unManager_getUnDistributedControlManagerNumber(), iManNum, "unDistributedControl.ctl does not have the excepted manager number");
}

void test_unManager_checkUnBackupManagersNumber(){
  int iManNum;
  fwInstallationManager_getNum("WCCOActrl", "unBackup.ctl", iManNum);
  assertEqual( unManager_getUnBackupManagerNumber(), iManNum, "unBackup.ctl does not have the excepted manager number");
}

void test_unManager_checkUnDeviceListUpdateManagersNumber(){
  int iManNum;
  fwInstallationManager_getNum("WCCOActrl", "unDeviceListUpdate.ctl", iManNum);
  assertEqual( unManager_getUnDeviceListUpdateManagerNumber(), iManNum, "unDeviceListUpdate.ctl does not have the excepted manager number");
}

//-------------------------------------------------------------------------
void test_unManager_isUnicosScriptRunning(){
  //we always except unicos_scripts.lst to be running
  dyn_string dsException;
  bool bIsRunning = unManager_isUnicosScriptsRunning(getSystemName(), dsException);
  assertTrue( bIsRunning, "unicos_scripts.lst is not running");
}

//-------------------------------------------------------------------------
void test_unManager_isUnDistributedControlRunning(){
  //we always except unDistributedControl to be running
  dyn_string dsException;
  bool bIsRunning = unManager_isUnDistributedControlRunning(getSystemName(), dsException);
  assertTrue( bIsRunning, "unDistributedControl.ctl is not running");
}

//-------------------------------------------------------------------------
void test_unManager_modifyManagerCommandLine(){
  string sCmdWoNum = "test/unManager/unManager.ctl";
  int iExceptedManNum = 120;
  string sCmdWithNum = "test/unManager/unManager.ctl -num "+iExceptedManNum;

  //we first test that the test manager is not present
  int iManNum;
  fwInstallationManager_getNum("WCCOActrl", sCmdWoNum, iManNum); //it is normal to get an error in the log as manager does not exist
  assertEqual( -1, iManNum, "Test manager is already present ("+sCmdWoNum+"), cannnot proceed with the rest of the test");

  //get the number of manager before adding it
  dyn_dyn_mixed ddmManagersInfoBefore;
  fwInstallationManager_pmonGetManagers( ddmManagersInfoBefore);
  int iNumManagersBefore = dynlen( ddmManagersInfoBefore[FW_INSTALLATION_MANAGER_PMON_IDX]);

  //we now add the manager w/o number
  unCorePostInstall_modifyManagerCommandIfExistOrAdd("WCCOActrl", sCmdWoNum, sCmdWoNum);

  //get the num of manager after the addition
  dyn_dyn_mixed ddmManagersInfoAfter;
  fwInstallationManager_pmonGetManagers( ddmManagersInfoAfter);
  int iNumManagersAfter = dynlen( ddmManagersInfoAfter[FW_INSTALLATION_MANAGER_PMON_IDX]);
  assertEqual( (int)(iNumManagersBefore+1), iNumManagersAfter, "Manager did not seem to be added properly: the number of managers did not increment by 1 as expected.");

  //and we modify its command line 
  unCorePostInstall_modifyManagerCommandIfExistOrAdd( "WCCOActrl", sCmdWoNum, sCmdWithNum);

  //We should now have the correct manager number
  fwInstallationManager_getNum("WCCOActrl", sCmdWoNum, iManNum);
  assertEqual( iExceptedManNum, iManNum, "The manager number is not the expected one after modifying the command line");

  //cleanup the manager console
  fwInstallationManager_remove("WCCOActrl", sCmdWithNum);
}

//--------------------------------------------------------------------------
void test_unManager_addUnDistributedControlManagerWithoutNumber(){
  //here we test the special case of adding unDistributedControl
  //The manager is added to the console by JCOP but the manager number is
  //added by the postinstall of UNICOS. We want to make sure that
  //by adding the manager w/o number it does not create a new entry
  //in the console duplicating the one of the manager with number

  //first get the count of manager
  dyn_dyn_mixed ddmManagersInfoBefore;
  fwInstallationManager_pmonGetManagers( ddmManagersInfoBefore);
  int iNumManagersBefore = dynlen( ddmManagersInfoBefore[FW_INSTALLATION_MANAGER_PMON_IDX]);

  //this is what is done by the postinstall of unDistributedControl
  fwInstallationManager_add("WCCOActrl", "always", 30, 3, 2, "unDistributedControl.ctl"); 

  //first get the count of manager after
  dyn_dyn_mixed ddmManagersInfoAfter;
  fwInstallationManager_pmonGetManagers( ddmManagersInfoAfter);
  int iNumManagersAfter = dynlen( ddmManagersInfoAfter[FW_INSTALLATION_MANAGER_PMON_IDX]);

  //we expect the same number of managers
  assertEqual( ddmManagersInfoBefore, ddmManagersInfoAfter, 
              "The number of managers have changed after adding an already existing manager while it should have stayed the same. Number before:"+iNumManagersBefore+ ", Number after:"+iNumManagersAfter);
}

